<?php

defined( 'ABSPATH' ) || exit;

include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
if(!is_plugin_active( 'word-balloon-pro/word-balloon-pro.php' )):

	
	function word_balloon_add_menu() {

		require_once WORD_BALLOON_DIR . 'inc/admin/admin_edit.php';

		$w_b_submenu_page = add_options_page(__('Setting Up Word Balloon','word-balloon'),'Word Balloon', 'administrator', 'word-balloon','word_balloon_admin_page');
		add_action( "admin_print_scripts-$w_b_submenu_page", 'word_balloon_only_edit_page_scripts' );

	}
	add_action( 'admin_menu', 'word_balloon_add_menu' );

	require_once WORD_BALLOON_DIR . 'inc/create_db.php';
	register_activation_hook( __FILE__, 'word_balloon_create_db' );


	add_action( 'plugins_loaded', 'word_balloon_update_db_check' );

endif;


function word_balloon_update_db_check() {

	if ( get_option( 'word_balloon_db_version' ) != WORD_BALLOON_VERSION ) {

		require_once WORD_BALLOON_DIR . 'inc/create_db.php';
		word_balloon_create_db();

	}

}


require_once WORD_BALLOON_DIR . 'inc/ajax_nonce.php';
add_action( 'wp_ajax_word_balloon_nonce_action_center', 'word_balloon_nonce_action_event' );



function word_balloon_only_edit_page_scripts() {




	
	wp_enqueue_media();

	
	wp_enqueue_script( 'jquery-ui-dialog' );
	wp_enqueue_style( 'wp-jquery-ui-dialog' );

	wp_enqueue_style('word_balloon_admin', WORD_BALLOON_URI . 'css/word_balloon_admin.min.css',array(),WORD_BALLOON_VERSION);
	wp_enqueue_style('word_balloon_edit', WORD_BALLOON_URI . 'css/word_balloon_edit.min.css',array('word_balloon_admin'),WORD_BALLOON_VERSION);
	wp_enqueue_style('word_balloon_font', WORD_BALLOON_URI . 'css/font/style.min.css',array(),WORD_BALLOON_VERSION);
	//add_action( 'wp_enqueue_scripts', 'word_balloon_translations_edit' );
	wp_register_script('word_balloon_edit', WORD_BALLOON_URI . 'js/word_balloon_edit.min.js',array( ),WORD_BALLOON_VERSION,true);
	wp_enqueue_script('word_balloon_edit');

	
	$translations = word_balloon_scriput_translations();
	wp_localize_script( 'word_balloon_edit', 'translations', $translations );
	
	wp_localize_script('word_balloon_edit','word_balloon_nonce_ajax_object',array(
		'ajax_url' => admin_url('admin-ajax.php'),
		'action' => 'word_balloon_nonce_action_center',
		'nonce' => wp_create_nonce("word_balloon_nonce_action_center"),
		
	));


}





require_once WORD_BALLOON_DIR . 'inc/admin/admin_block.php';
add_action('enqueue_block_editor_assets', 'word_balloon_block_control_panel');



require_once WORD_BALLOON_DIR . 'inc/admin/admin_enqueue.php';
add_action( 'admin_enqueue_scripts', 'word_balloon_custom_enqueue' );

// TinyMCEにボタン追加
function word_balloon_tinymce_button() {
	if ( current_user_can( 'edit_posts' ) && current_user_can( 'edit_pages' ) ) {
		add_filter( 'mce_buttons', 'word_balloon_register_tinymce_button' );
		add_filter( 'mce_external_plugins', 'word_balloon_tinymce_button_script' );
	}
}
add_action( 'admin_init', 'word_balloon_tinymce_button' );


function word_balloon_register_tinymce_button( $buttons ) {
	array_push( $buttons, 'word_balloon_button' );
	array_push( $buttons, 'word_balloon_restore_button' );
	return $buttons;
}


function word_balloon_tinymce_button_script( $plugin_array ) {
	$plugin_array['word_balloon_script'] = WORD_BALLOON_URI . 'js/word_balloon_tinymce.min.js';
	return $plugin_array;
}


function custom_add_quicktags() {
	if (wp_script_is('quicktags')){
		?>
		<script>
			function word_balloon_callback() { jQuery('#w_b_modal_open').click(); }
			QTags.addButton( 'word_balloon', '<?php echo esc_html_x('Word Balloon','text_button','word-balloon'); ?>', word_balloon_callback );
			function word_balloon_restore_callback() { jQuery('#w_b_restore_copy').click(); }
			QTags.addButton( 'word_balloon_restore', '<?php echo esc_html_x('Restore Balloon','text_button','word-balloon'); ?>', word_balloon_restore_callback );
		</script>
		<?php
	}
}
add_action( 'admin_print_footer_scripts', 'custom_add_quicktags' );

function word_balloon_custom_edit_style(){
	echo '<style type="text/css" id="w_b_css"></style>';
}

function word_balloon_scriput_translations() {
	return array(
		'select_an_avatar' => __( 'Select an avatar', 'word-balloon' ),
		'select' => __( 'Select', 'word-balloon' ),
		'select_a_photo' => __( 'Select a photo', 'word-balloon' ),
		'do_you_want_to_delete' => __( 'Do you want to delete the avatar?', 'word-balloon' ),
		'really_remove_avatar' => __( 'Really remove avatar from the system?', 'word-balloon' ),
		'edit_avatar' => __( 'Edit Avatar', 'word-balloon' ),
		'edit_avatar_name' => __( 'Name', 'word-balloon' ),
		'edit_avatar_note' => __( 'Note', 'word-balloon' ),
		'edit_avatar_update' => __( 'Update', 'word-balloon' ),
		'edit_avatar_cancel' => __( 'Cancel', 'word-balloon' ),
		'edit_avatar_priority' => __( 'Priority', 'word-balloon' ),
		'anonymous' => __( 'John Doe', 'word-balloon' ),
		'select_wallpaper' => __( 'Select a wallpaper', 'word-balloon' ),
		'select_a_sound' => __( 'Select a sound', 'word-balloon' ),
		'dialog_wallpaper' => __( 'Wallpaper', 'word-balloon' ),
		'dialog_side_by_side' => __( 'Side by side box', 'word-balloon' ),
		'dialog_restore' => __( 'Restore', 'word-balloon' ),
	);
}




add_action( 'enqueue_block_editor_assets', 'word_balloon_user_styles' );




function word_balloon_extend_tiny_mce_before_init( $mce_init ) {
	$mce_init['cache_suffix'] = 'v='.time();
	return $mce_init;
}
add_filter( 'tiny_mce_before_init', 'word_balloon_extend_tiny_mce_before_init' );




if ( ! function_exists( 'word_balloon_pro_plugin_action_links' ) ) :
	function word_balloon_plugin_action_links($links, $file) {
		if ('word-balloon/word-balloon.php' == $file  && current_user_can( 'manage_options' )) {
			$settings_link = '<a href="' . admin_url( 'options-general.php?page=word-balloon' ) . '">'.__( 'Settings', 'word-balloon' ).'</a>';
			array_unshift($links, $settings_link);
		}
		return $links;
	}
	add_filter('plugin_action_links', 'word_balloon_plugin_action_links', 10, 2);
endif;

function word_balloon_old_wp() {
	echo '<style type="text/css" id="w_b_old_css">#w_b_overlay .wp-color-result {
		-webkit-box-sizing: content-box;
		-moz-box-sizing: content-box;
		-o-box-sizing: content-box;
		-ms-box-sizing: content-box;
		box-sizing: content-box;
	}</style>';

}


function word_balloon_update_check() {

	if ( get_site_option( 'word_balloon_version' ) != WORD_BALLOON_VERSION ) {
		update_option( 'word_balloon_version', WORD_BALLOON_VERSION );

		
		include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		if(is_plugin_active( 'word-balloon-pro/word-balloon-pro.php' )){
			if (defined("WORD_BALLOON_PRO_DIR")) {
				require_once WORD_BALLOON_PRO_DIR . 'inc/build_style.php';
				if ( function_exists( 'word_balloon_pro_build_css_file' ) ){
					word_balloon_pro_build_css_file();
					return;
				}
				
				if ( function_exists( 'word_balloon_build_css_file' ) ){
					word_balloon_build_css_file();
				}
			}
		}

	}
}
add_action( 'plugins_loaded', 'word_balloon_update_check' );
